$(function(){

	var win = window;

	var DH_MobileUtil = (function(){
		
		/***
		*  FastClick库要在mobile.js之前引用 
		*	利用FastClick库解决移动端轻击(tap)300毫秒延迟
		*/
		var _initFastClickHandler = function(){
			if( typeof FastClick != undefined ) { 
		      FastClick.attach(document.body);   
		   }
		}	


		/***
		*  图片加载完成后进行的操作
		*  _loadedImage($images, fn)
		*  $images --- jQuery对象, 需要加载完成的图片
		*  fn     --- 回调函数，   图片加载完成后的回调函数
		*/
		var _loadedImage = function($images, fn){
			if( !$images || !fn ) return;
			var timer, isLoaded = true;
			$images.each(function(){	
				if ( $(this).height() === 0 ) {
					isLoaded = false;
					return false;	
				}	
			});	
			if ( isLoaded ) {
				clearTimeout(timer);
				if ( fn ) fn();
			} else{
				isLoaded = true;
				setTimeout(function(){
					_loadedImage($images, fn);
				},500);
			}
		};	


		/***
		*  _bxSliderAction($slider, options)
		*  $slider  --- 要滑动的元素
		*  options  --- bxSilder的参数
		*  (常用的)controls, captions,auto,speed,swipeThreshold,infiniteLoop,pagerType 
		*/
		var _bxSliderAction = function($slider, options){
			if( !$slider ) return;
			$slider.bxSlider(options);
		};


		/***
		*  _tapToggleAction($obj,classname,hlgFn,normalFn)
		*  $obj       --- 要轻击的元素
		*  classname  --- 控制状态变化的class
		*  hlgFn      --- 添加classname后的回调函数, 返回参数为当前绑定事件的对象
		*  normalFn   --- 移除classname后的回调函数, 返回参数为当前绑定事件的对象
		*/
		var _tapToggleAction = function($obj, classname, hlgFn, normalFn){
			if ( !$obj ) return;
			$obj.on("click", function(){
				if( !$(this).hasClass(classname) ){
					$(this).addClass(classname);
					if( hlgFn ) hlgFn($(this));
				}else{
					$(this).removeClass(classname);
					if( normalFn ) normalFn($(this));	
				}
			});
		}; 


		/***
		*  _singleTapAction($obj, fn)
		*  $obj --- 要轻击的元素
		*  fn   --- 回调函数, 返回参数为当前绑定事件的对象
		*/
		var _singleTapAction = function($obj, fn){
			if ( !$obj ) return;
			$obj.on("click", function(){
				if( fn ) fn( $(this) );
			});
		};

		/***
		*  _formKitsFocusToggle($obj, fn)
		*  $obj     --- 获取/失去焦点的表单元素
		*  focusFn  --- 获取焦点的回调函数, 返回参数为当前绑定事件的对象
		*  blurFn   --- 失去焦点的回调函数, 返回参数为当前绑定事件的对象
		*/	
		var _formKitsFocusToggle = function($obj, focusFn, blurFn){
			if ( !$obj ) return;
			$obj.on("focus", function(){
			   if( focusFn ) focusFn( $(this) ); 	  
			});	
			$obj.on("blur", function(){
				if( blurFn ) blurFn( $(this) );
			});
		};
		
		/***
		*  _overlayToggle($trigger, $overlay, $closeBtn, closeFn)
		*	$trigger   --- 使覆盖层显示的元素，起触发作用
		*  $overlay   --- 覆盖层
		*  $close     --- 隐藏覆盖层的元素, 非必须传
      *  contentClass   --- 覆盖层元素中主要内容的class
		*  fns : willShowFn  --- 当覆盖层还没有显示好的回调函数, 返回参数为当前绑定事件的对象
		*  fns : didShowFn   --- 当覆盖层已经显示好的回调函数, 返回参数为当前绑定事件的对象
		*  fns : didCloseFn  --- 当覆盖层已经隐藏后的回调函数, 返回参数为当前绑定事件的对象
		*/
		var _overlayToggle = function($trigger, $overlay, $close, contentClass, fns){
			if ( !$overlay || !$trigger ) return;

			$trigger.on("click", function(){
		    	if( fns.willShowFn ) fns.willShowFn( $(this) );
		    	$overlay.fadeIn("fast", function(){
		    		if( typeof fns.didShowFn === "function") fns.didShowFn( $(this) );
		    	});
		   });
		   $overlay.on("click", function(evt){
				if( !$(evt.target).hasClass(contentClass) && !$(evt.target).parents().hasClass(contentClass) ){
					$(this).fadeOut("fast", function(){
						if( fns.didCloseFn ) fns.didCloseFn( $(this) );	
					});	
				}
			});
			if( $close ){
				$close.on("click", function(evt){
					$overlay.fadeOut("fast", function(){
						if( fns.didCloseFn ) fns.didCloseFn( $(this) );			
					});	
				});		
			}
		};		


		var _setFontsizeForRootNode = function(fontsize){
			var doc = document, win = window,
				 docEl = doc.documentElement,
        		 resizeEvt = 'orientationchange' in window ? 'orientationchange' : 'resize',
             recalc = function () {
                var clientWidth = docEl.clientWidth;
                if (!clientWidth) return;
                docEl.style.fontSize = fontsize * (clientWidth / 320) + 'px';
             };

		    if (!doc.addEventListener) return;
		    win.addEventListener(resizeEvt, recalc, false);
		    win.addEventListener("load", recalc, false);
		    doc.addEventListener('DOMContentLoaded', recalc, false);
		};
		

		var _storageUtil = (function(){
			var storage = win.localStorage;
			return {
				getData : function(key){
					return storage.getItem(key);
				},
				setData : function(key, value){
					storage.setItem(key, value);
				},
			};
		})();

		return {

			initFastClickHandler   :  _initFastClickHandler,
			loadedImage            :  _loadedImage,
			bxSliderAction         :  _bxSliderAction, 
			tapToggleAction        :  _tapToggleAction,
			singleTapAction        :  _singleTapAction,
			formKitsFocusToggle    :  _formKitsFocusToggle,
			overlayToggle          :  _overlayToggle,
			setFontsizeForRootNode : _setFontsizeForRootNode,
			storageUtil            : _storageUtil
		};	

		/***
		*  
		*/

	})();

	if ( !window.DH_MobileUtil ) {
      window.DH_MobileUtil = DH_MobileUtil;
   } 

   DH_MobileUtil.initFastClickHandler();

});





